<!-- block content -->
<section class="container post">
    <article>
        <header>
            <h1 class="title">{{ page.title }}</h1>
        </header>
        <p>{{ page.content }}</p>
    </article>
</section>
<!-- endblock -->