<!-- block footer -->
<footer class="pt-4 my-md-5 pt-md-5 border-top">
    <div class="row">
        <div class="col-12 col-md">
            {%- block footer %}
                {% include "/modules/copyright.html" %}
            {%- endblock %}
        </div>
    </div>
</footer>
<!-- endblock -->